@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -33,7 +33,7 @@ void ConfigFile::create()
 {
     Q_EMIT info(i18n("Writing config file for %1...", m_name));
 
-    foreach (const Config &c, m_configData) {
+    for (const Config &c : qAsConst(m_configData)) {
         KConfigGroup grp = m_config->group(c.group);
         if (c.obscure) {
             grp.writeEntry(c.key, KStringHandler::obscure(c.value));
